@@ -1,4 +1,4 @@
+from palp.sequence.sequence_redis_item import FIFOItemRedisSequence
 from palp.sequence.sequence_memory import FIFOMemorySequence, LIFOMemorySequence, PriorityMemorySequence
-from palp.sequence.sequence_redis_item import FIFOItemRedisSequence, LIFOItemRedisSequence
 from palp.sequence.sequence_redis_request import FIFORequestRedisSequence, LIFORequestRedisSequence, \
     PriorityRequestRedisSequence
